@@ -19,11 +19,11 @@ from sklearn.metrics import roc_auc_score
 
 class Pseudo(object):
 
-    def __init__(self, X, y, X_test, confidences=(0.01, 0.99), **kwargs):
+    def __init__(self, X, y, X_test, confidences=(0.01, 0.01), **kwargs):
         self.X = X
         self.y = y
         self.X_test = X_test
-        self.confidences = confidences
+        self.confidences = confidences  # 加入训练的样本比例： 正、负比例 # todo: 百分位数或者个数，分正负
 
     def run(self, n_iter=1):
         X, y = self.X.copy(), self.y.copy()
@@ -48,13 +48,14 @@ class Pseudo(object):
         """
         clf = LGBMClassifier()
         clf.fit(X, y)
-        score = roc_auc_score(y, clf.predict_proba(X)[:, 1]) # 验证方式？？？线下训练集CV
+        score = roc_auc_score(y, clf.predict_proba(X)[:, 1])  # 验证方式？？？线下训练集CV
         test_preds = clf.predict_proba(X_test)
         return clf, score, test_preds
 
     def pseudo_labeling(self, preds):
         thresholds = np.quantile(preds, self.confidences)  # 计算上下分位数
-        print(thresholds)
+        print(f"Thresholds: {thresholds}")
+
         pos_index = np.where(preds < thresholds[1])[0]
         neg_index = np.where(preds < thresholds[0])[0]
 
