@@ -7,10 +7,13 @@ __mtime__ = '18-12-14'
 """
 from .utils.xx import xx
 from .utils import cprint
+from .utils.pandas_utils import reduce_mem_usage
 
 #########################################################################
 import os
+import gc
 import re
+import sys
 import json
 import pickle
 import inspect
@@ -43,6 +46,10 @@ ip = localhost
 local_info = {'hostname': hostname, 'localhost': localhost, 'ip': localhost}
 
 is_dev = True if hostname.__contains__("yuanjie") else False
+
+getsize = lambda obj: sys.getsizeof(obj) / 1024 ** 2  # M
+
+getsize_df = lambda df: df.memory_usage().sum() / 1024 ** 2  #
 ###################################################################
 
 
@@ -59,7 +66,6 @@ sns.set_context('paper')
 
 #########################################################################
 
-
 # 序列化
 def df2hdf(df, file='./data.h5'):
     df.to_hdf(file, 'w', complib='blosc', complevel=8)
@@ -71,6 +77,11 @@ def reader(fname='./tmp.txt', sep=',', mode='r'):
             yield l.strip().split(sep)
 
 
+def xpickle_load(file):
+    with open(file, 'rb') as f:
+        return pickle.load(f)
+
+
 @xx
 def xwrite(iterable, fname, mode='w', glue='\n'):
     with open(fname, mode) as f:
@@ -84,12 +95,6 @@ def xpickle_dump(objs, file='tmp.pkl'):
         pickle.dump(objs, f)
 
 
-@xx
-def xpickle_load(file):
-    with open(file, 'rb') as f:
-        return pickle.load(f)
-
-
 # 统计函数: 待补充groupby.agg
 # xsummary = xx(lambda iterable: DataFrameSummary(list(iterable) | xDataframe)['iterable'])
 xvalue_counts = xx(
@@ -112,6 +117,13 @@ xmin_index = xx(lambda x: min(range(len(x)), key=x.__getitem__))  # 列表中最
 xmost_freq = xx(lambda x: max(set(x), key=x.count))  # 查找列表中频率最高的值, key作用于set(x), 可类推出其他用法
 
 
+# gc
+@xx
+def xgc(iterable):
+    del iterable
+    gc.collect()
+
+
 # print
 @xx
 def xprint(obj, mode=None, bg='blue'):
